package initialize

import (
	"go.mongodb.org/mongo-driver/mongo"
	"go.uber.org/zap"
	"gitea.pena/PenaSide/tariffs/internal/repository/privilege"
	"gitea.pena/PenaSide/tariffs/internal/repository/tariff"
)

type RepositoryDeps struct {
	Logger *zap.Logger
	Mdb    *mongo.Database
}

type Repository struct {
	PrivilegeRepo *privilege.Privilege
	TariffRepo    *tariff.Tariff
}

func NewRepository(deps RepositoryDeps) *Repository {
	return &Repository{
		PrivilegeRepo: privilege.NewPrivilegeRepo(privilege.Deps{
			Mdb:    deps.Mdb.Collection("privileges"),
			Logger: deps.Logger,
		}),
		TariffRepo: tariff.NewTariffRepo(tariff.Deps{
			Mdb:         deps.Mdb.Collection("tariffs"),
			Logger:      deps.Logger,
			PrivilegeDB: deps.Mdb.Collection("privileges"),
		}),
	}
}
